@@ -15,7 +15,8 @@ libddww = ct.cdll.LoadLibrary(wwlib)
 for key, val in sfdics.obj_name.items():
     exec('%s=%d' %(val, key))
 for key, val in sfdics.typ2descr.items():
-    exec('%s=%d' %(val, key))
+    if key is not None:
+        exec('%s=%d' %(val, key))
 
 
 def getError(error):
